# BLS Provider Extension

This extension integrates the BLS data provider into the OpenBB Platform.

## Installation

To install this extension from PyPI:

```console
pip install openbb-bls
```

To install the extension locally, run the following command in this folder:

```console
poetry install
```

Documentation available [here](https://docs.openbb.co/platform/developer_guide/contributing).
